Method: ActiveWarehouse::Cube.reports_on

Defined in:
lib/active_warehouse/cube.rb

.reports_on(fact_name) ⇒ Object Also known as: report_on

Defines the fact name, without the ‘Fact’ suffix, that this cube reports on. For instance, if you have PurchaseFact, you could then call reports_on :purchase.

The default value for reports_on is to take the name of the cube, i.e. PurchaseCube, and remove the Cube suffix. The assumption is that your Cube name matches your Fact name.



50
51
52
# File 'lib/active_warehouse/cube.rb', line 50

def reports_on(fact_name)
  @fact_name = fact_name
end